systemd

package
v0.6.0-rc.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 30, 2025 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Overview

Package systemd provides the systemd artifacts and variables for the gpud server.

Index

Constants

const (
	DefaultEnvFile  = "/etc/default/gpud"
	DefaultUnitFile = "/etc/systemd/system/gpud.service"

	DeprecatedDefaultBinPathSbin = "/usr/sbin/gpud"
	DefaultBinPath               = "/usr/local/bin/gpud"
)

Variables

This section is empty.

Functions

func CreateDefaultEnvFile

func CreateDefaultEnvFile(endpoint string) error

CreateDefaultEnvFile creates the default environment file for gpud systemd service. Assume systemdctl is already installed, and runs on the linux system.

func DefaultBinExists

func DefaultBinExists() bool

func GPUdServiceUnitFileContents added in v0.5.0

func GPUdServiceUnitFileContents() string

Types

This section is empty.

Jump to