Documentation
¶
Overview ¶
Package systemd provides the systemd artifacts and variables for the gpud server.
Index ¶
Constants ¶
const ( DefaultEnvFile = "/etc/default/gpud" DefaultUnitFile = "/etc/systemd/system/gpud.service" DeprecatedDefaultBinPathSbin = "/usr/sbin/gpud" DefaultBinPath = "/usr/local/bin/gpud" )
Variables ¶
This section is empty.
Functions ¶
func CreateDefaultEnvFile ¶
CreateDefaultEnvFile creates the default environment file for gpud systemd service. Assume systemdctl is already installed, and runs on the linux system.
func DefaultBinExists ¶
func DefaultBinExists() bool
func GPUdServiceUnitFileContents ¶ added in v0.5.0
func GPUdServiceUnitFileContents() string
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.